import bb.cascades 1.0
import com.ysal.ocrscan 1.0

SettingsPage {
    titleBar: TitleBar {
        id: pageTitleBar
        objectName: "titleBar"
        kind: TitleBarKind.Default
        title: qsTr("Settings")
    }
    id: page

	ScrollView {
        scrollViewProperties.scrollMode: ScrollMode.Vertical
        scrollViewProperties.pinchToZoomEnabled: false
        scrollViewProperties.overScrollEffectMode: OverScrollEffectMode.OnPinchAndScroll
        Container {
	        topPadding: 20.0
	        leftPadding: 20.0
	        rightPadding: 20.0
            Label {
                text: qsTr("General Settings")
                textStyle.fontStyle: FontStyle.Italic
                textStyle.fontWeight: FontWeight.Bold
            }       
            DropDown {
                id: modeDeropdown
                
                function themeDark() {
                    return Application.themeSupport.theme.colorTheme.style == VisualStyle.Dark;
                }
                
                objectName: "mode"
                title: qsTr("Scan Mode")
                Option {
                    imageSource: modeDeropdown.themeDark() ? "asset:///images/text1.png" : "asset:///images/text1_dark.png" 
                    text: qsTr("Document")
                    description: qsTr("Works best for flat pages")
                    selected: controller.mode == 1
                    onSelectedChanged: {
                        if (selected) {
                            controller.mode = 1;
                        }
                    }
                }
                Option {
                    imageSource: modeDeropdown.themeDark() ? "asset:///images/book.png" : "asset:///images/book_dark.png" 
                    text: qsTr("Book")
                    description: qsTr("Use for non-flat pages such as book")
                    selected: controller.mode == 2
                    onSelectedChanged: {
                        if (selected) {
                            controller.mode = 2;
                        }
                    }
                }
            }    
            Divider {
                topMargin: 50
                bottomMargin: 50
            }
	        Label {
	            text: qsTr("Text Extraction Settings")
	            textStyle.fontStyle: FontStyle.Italic
	            textStyle.fontWeight: FontWeight.Bold
	        }       
	        DropDown {
	            objectName: "language"
	            title: qsTr("Language")
	        }
	        CheckBox {
            	text: qsTr("Keep original line breaks")
            	checked: controller.keepLinebreaks
            	onCheckedChanged: {
                    controller.keepLinebreaks = checked;
                }
            }  
	        Divider {
                topMargin: 50
                bottomMargin: 50	            
	        }
	        Label {
	            text: qsTr("PDF Settings")
	            textStyle.fontStyle: FontStyle.Italic
                textStyle.fontWeight: FontWeight.Bold
	        }
            DropDown {
                objectName: "output"
                title: qsTr("Output")
                options: [
                    Option {
                        text: qsTr("Grayscale")
                        selected: true
                    },
                    Option {
                        text: qsTr("Color")
                    }
                ]
            }
	        DropDown {
	            objectName: "paper"
	            title: qsTr("Paper Size")
	        }
	        Container {
	            layout: StackLayout {
	                orientation: LayoutOrientation.LeftToRight
	            }
	            Label {
	                objectName: "lblMargins"
	                text: qsTr("Margins:")
	            }
	            Container {
	                layout: StackLayout {
                        orientation: LayoutOrientation.LeftToRight
                    }
	                horizontalAlignment: HorizontalAlignment.Fill
	                //minHeight: 300.0
                    TextField {
                        objectName: "marginLeft"
                        hintText: "Left"
                        inputMode: TextFieldInputMode.NumbersAndPunctuation
                        horizontalAlignment: HorizontalAlignment.Left
                        verticalAlignment: VerticalAlignment.Center
                        maxWidth: 170.0
                    }
                    Container {
                        layout: StackLayout {
                            orientation: LayoutOrientation.TopToBottom
                        }

                        TextField {
		                    objectName: "marginTop"
		                    hintText: "Top"
		                    inputMode: TextFieldInputMode.NumbersAndPunctuation
		                    horizontalAlignment: HorizontalAlignment.Center
		                    verticalAlignment: VerticalAlignment.Top
		                    maxWidth: 170.0
		                }
	                    DropDown {
	                        objectName: "marginUnit"
	                        verticalAlignment: VerticalAlignment.Center
	                        horizontalAlignment: HorizontalAlignment.Center
	                        maxWidth: 150.0
	                        Option {
	                            text: "inches"
	                            selected: true
	                        }
	                        Option {
	                            text: "mm"
	                        }
	                    }
	                    TextField {
	                        objectName: "marginBottom"
	                        hintText: "Bottom"
	                        inputMode: TextFieldInputMode.NumbersAndPunctuation
	                        horizontalAlignment: HorizontalAlignment.Center
	                        verticalAlignment: VerticalAlignment.Bottom
	                        maxWidth: 170.0
	                    }
                    }
	                
	                TextField {
	                    objectName: "marginRight"
	                    hintText: "Right"
	                    inputMode: TextFieldInputMode.NumbersAndPunctuation
	                    horizontalAlignment: HorizontalAlignment.Right
	                    verticalAlignment: VerticalAlignment.Center
	                    maxWidth: 170.0
	                }
	
	            }
	
	        }

            Label {
                text: qsTr("Image quality:")
            }
            Container {
                horizontalAlignment: HorizontalAlignment.Fill
                layout: DockLayout {
                }
                Label {
                    text: qsTr("Lower")
                    horizontalAlignment: HorizontalAlignment.Left
                }
                Label {
                    id: imgQuality
                    text: "75%"
                    horizontalAlignment: HorizontalAlignment.Center
                }
                Label {
                    text: qsTr("Higher")
                    horizontalAlignment: HorizontalAlignment.Right
                }
            }
            Container {
                layout: DockLayout {
                }
                Slider {
                    id: slider
                    objectName: "compression"
                    horizontalAlignment: HorizontalAlignment.Fill
                    verticalAlignment: VerticalAlignment.Bottom
                    value: 75
                    fromValue: 50
                    toValue: 100
                    onValueChanged: {
                        imgQuality.text = slider.value.toFixed(0) + "%";
                        //controller.saveSettings();
                    }
                }
            }
            Container {
                horizontalAlignment: HorizontalAlignment.Fill
                layout: DockLayout {
                }
                Label {
                    text: qsTr("Smaller file")
                    horizontalAlignment: HorizontalAlignment.Left
                }
                Label {
                    text: qsTr("Larger file")
                    horizontalAlignment: HorizontalAlignment.Right
                }
            }
        }
	}
    onCreationCompleted: {
        page.init();
    }
    }
