// Navigation pane project template
import bb.cascades 1.0
import bb.cascades.multimedia 1.0
import bb.multimedia 1.0
import bb.system 1.0
import com.ysal.ocrscan 1.0

TabbedPane {    
    id: tabbedPane
    showTabsOnActionBar: false
    Tab {
        title: qsTr("Camera")
        description: qsTr("Take photo of the document")
        imageSource: "asset:///images/photo.png"
        objectName: "cameraTab"
        NavigationPane {
            objectName: "navigationPane"
            Page {
	            id: cameraPage
	            objectName: "cameraPage"
	            Container {
	                objectName: "mainContainer"
	                background: Color.Black
	                layout: DockLayout {
	                }
	                OcrCamera {
	                    id: camera
	                    objectName: "camera"
	                    property bool isActive
	                    horizontalAlignment: HorizontalAlignment.Fill
	                    verticalAlignment: VerticalAlignment.Fill
	                    isActive: false
	                    gestureHandlers: [
	                        TapHandler {
	                            onTapped: {
	                                scanner.cancel = false;
	                                camera.takePicture();
	                            }
	                        }
	                    ]
	                }
	                ImageView {
	                    id: overlay
	                    objectName: "overlay"
	                    horizontalAlignment: HorizontalAlignment.Center
	                    verticalAlignment: VerticalAlignment.Center
	                    gestureHandlers: [
	                        TapHandler {
	                            onTapped: {
	                                scanner.cancel = false;
	                                camera.takePicture();
	                            }
	                        }
	                    ]
	                }
	                Container {
	                    id: lang
	                    layout: DockLayout {
	                    }
	                    objectName: "lang"
	                    leftMargin: 60.0
	                    topMargin: 60.0
	                    ImageView {
	                        id: langBtn
	                        //scalingMethod: ScalingMethod.None
	                        imageSource: "asset:///images/mini_menu_bgnd.png"
	                        verticalAlignment: VerticalAlignment.Center
	                        horizontalAlignment: HorizontalAlignment.Center
	                    }
	                    Label {
	                        objectName: "langName"
	                        text: "EN"
	                        verticalAlignment: VerticalAlignment.Center
	                        horizontalAlignment: HorizontalAlignment.Center
	                        textStyle.color: Color.White
	                    }
	                    gestureHandlers: [
	                        TapHandler {
	                            onTapped: {
	                                controller.selectLanguage();
	                            }
	                        }
	                    ]
	                }
	            }
	            actions: [
	                ActionItem {
	                    objectName: "languageAction"
	                    title: qsTr("Language")
	                    imageSource: "asset:///images/ic_globe.png"
	                    ActionBar.placement: ActionBarPlacement.OnBar
	                    onTriggered: {
	                        controller.selectLanguage();
	                    }
	                },	 	                               
                    ActionItem {
                        objectName: "modeAction"
                        title: qsTr("Mode")
                        imageSource: controller.mode == 2 ? "asset:///images/book.png" : "asset:///images/text1.png" 
                        ActionBar.placement: ActionBarPlacement.OnBar
                        onTriggered: {
                            controller.selectMode();
                        }
                    },
	                ActionItem {
	                    objectName: "flashAction"
	                    title: qsTr("Flash")
	                    imageSource: "asset:///images/ic_flash_auto.png"
	                    ActionBar.placement: ActionBarPlacement.OnBar
	                    onTriggered: {
	                        camera.changeFlashMode();
	                    }
	                },
                    ActionItem {
                        objectName: "openAction"
                        title: qsTr("Open File")
                        imageSource: "asset:///images/ic_open.png"
                        ActionBar.placement: ActionBarPlacement.OnBar
                        onTriggered: {
                            controller.openFile();
                        }
                    }
	            ]	            
	        }
	    }
        onCreationCompleted: {
            Application.cover = appCover.createObject();
            OrientationSupport.supportedDisplayOrientation = SupportedDisplayOrientation.All;
            camera.startViewfinder();
            camera.isActive = true;
        }
        attachedObjects: [
            ComponentDefinition {
                id: appCover
                source: "Cover.qml"
            },
            SystemProgressToast {
                id: progress
                objectName: "progress"
                body: qsTr("Processing image")
                button.label: qsTr("Cancel")
                onFinished: {
                    scanner.onCancel();
                }
            }
        ]
    }
    Tab {
        title: qsTr("Image")
        description: qsTr("Preview and Crop Image")
        imageSource: "asset:///images/crop.png"
        objectName: "previewTab"
        NavigationPane {
            objectName: "navigationPane"
            Page {
	            Container {
	                background: Color.DarkGray
	                PreviewView {
	                    objectName: "previewView"
	                }
	            }
	            actions: [
	                ActionItem {
	                    objectName: "extractAction"
	                    title: qsTr("Extract Text")
	                    enabled: false
	                    imageSource: "asset:///images/ic_text.png"
	                    ActionBar.placement: ActionBarPlacement.OnBar
	                    onTriggered: {
	                        controller.extractText();
	                        //camera.changeFlashMode();
	                    }
	                },
	                ActionItem {
	                    objectName: "addToPdfAction"
	                    title: qsTr("Add to PDF")
	                    enabled: false
	                    imageSource: "asset:///images/ic_pdf.png"
	                    ActionBar.placement: ActionBarPlacement.OnBar
	                    onTriggered: {
	                        controller.addPdfPage();
	                        //camera.changeFlashMode();
	                    }
	                }
	            ]
	        }
        }
    }
    Tab {
        title: qsTr("Text")
        description: qsTr("Extracted Text")
        imageSource: "asset:///images/ic_text.png"
        objectName: "resultTab"
        NavigationPane {
            objectName: "navigationPane"
            Page {
	            id: fullTextPage
	            objectName: "fullTextPage"
	            titleBar: TitleBar {
	                title: qsTr("Extracted Text")
	            }
	            Container {
	                TextArea {
	                    id: scannedText
	                    objectName: "fullText"
                        hintText: ""
                    }
	                ScrollView {
	                    objectName: "scannedTextContainer"
	                    Label {
	                        id: scannedTextRO
	                        objectName: "fullTextRO"
	                        multiline: true
	                    }
	                    scrollViewProperties {
	                        scrollMode: ScrollMode.Vertical
	                    }
	                }
	            }
	            actions: [
                    ActionItem {
                        title: qsTr("Add Page")
                        imageSource: "asset:///images/ic_add_page.png"
                        ActionBar.placement: ActionBarPlacement.InOverflow
                        onTriggered: {
                            controller.gotoCameraTab();
                        }
                    },
                    ActionItem {
                        title: qsTr("Save File")
                        enabled: scannedText.text || scannedTextRO.text
                        imageSource: "asset:///images/save.png"
                        ActionBar.placement: ActionBarPlacement.OnBar
                        onTriggered: {
                            controller.saveTxt();
                        }
                    },
	                ActionItem {
	                    title: qsTr("Share as Text")
                        enabled: scannedText.text || scannedTextRO.text
	                    imageSource: "asset:///images/share.png"
                        ActionBar.placement: ActionBarPlacement.OnBar
	                    onTriggered: {
	                        controller.shareText();
	                    }
	                },
	                ActionItem {
	                    title: qsTr("Share as File")
                        enabled: scannedText.text || scannedTextRO.text
	                    imageSource: "asset:///images/share1.png"
                        ActionBar.placement: ActionBarPlacement.OnBar
	                    onTriggered: {
	                        controller.shareFile();
	                    }
	                },
	                ActionItem {
	                    title: qsTr("Copy")
                        enabled: scannedText.text || scannedTextRO.text
	                    imageSource: "asset:///images/copy.png"
	                    ActionBar.placement: ActionBarPlacement.InOverflow
	                    onTriggered: {
	                        controller.copy();
	                    }
	                },
	                DeleteActionItem {
	                    title: qsTr("Done")
	                    imageSource: "asset:///images/accept.png"
	                    ActionBar.placement: ActionBarPlacement.InOverflow
	                    onTriggered: {
	                        controller.doneText();
	                    }
	                }
	            ]
	        }
        }
    }
    Tab {
        title: qsTr("PDF")
        description: qsTr("PDF")
        imageSource: "asset:///images/ic_pdf.png"
        objectName: "pdfTab"
        NavigationPane {
            objectName: "navigationPane"
            Page {
	            id: pdfPage
	            Container {
	                background: Color.LightGray
	                PdfPreviewView {
	                    id: pdfView
	                    visible: pdfView.pageCount > 0
	                    objectName: "pdfView"
	                    horizontalAlignment: HorizontalAlignment.Center
	                }
	                Container {
	                    topPadding: 40
	                    horizontalAlignment: HorizontalAlignment.Center
                        visible: pdfView.pageCount == 0
                        Label {
                        	text: qsTr("Empty")
                        }                     
                    }
	            }
	            actions: [
	                ActionItem {
	                    title: qsTr("Add Page")
	                    imageSource: "asset:///images/ic_add_page.png"
	                    ActionBar.placement: ActionBarPlacement.OnBar
	                    onTriggered: {
	                        controller.gotoCameraTab();
	                    }
	                },
	                ActionItem {
                        title: qsTr("Save PDF")
                        enabled: pdfView.pageCount > 0
                        imageSource: "asset:///images/save_pdf.png"
                        ActionBar.placement: ActionBarPlacement.OnBar
                        onTriggered: {
                            controller.savePdf();
                        }
                    },
                    ActionItem {
                        title: qsTr("Open PDF")
                        enabled: pdfView.pageCount > 0
                        imageSource: "asset:///images/ic_open.png"
                        ActionBar.placement: ActionBarPlacement.OnBar
                        onTriggered: {
                            controller.openPdf();
                        }
                    },
                    DeleteActionItem {
                        title: qsTr("Done")
                        imageSource: "asset:///images/accept.png"
                        ActionBar.placement: ActionBarPlacement.InOverflow
                        onTriggered: {
                            controller.donePdf();
                        }
                    }
                ]
	        }
        }
    }

    Menu.definition: MenuDefinition {

        actions: [
            ActionItem {
                title: qsTr("Help")
                imageSource: "images/ic_help.png"

                onTriggered: {
                    controller.displayHelp();
                }
            },
            ActionItem {
                title: qsTr("Settings")
                imageSource: "images/ic_settings.png"
                
                onTriggered: {
                    controller.displaySettings();
                }
            },
            ActionItem {
                title: qsTr("Share")
                imageSource: "images/share.png"
                
                onTriggered: {
                    controller.shareAppLink();
                }
            }
        ] // end of actions list
    } // end of MenuDefinition

}
